(citing)=

# Citing smolgp

If you use `smolgp` in your research, please cite [Rubenzahl et al. 2026](https://ui.adsabs.harvard.edu/abs/2026arXiv260102527R/abstract):
```
@ARTICLE{2026arXiv260102527R,
       author = {{Rubenzahl}, Ryan A. and {Hattori}, Soichiro and {S{\"a}rkk{\"a}}, Simo and {Farr}, Will M. and {Luhn}, Jacob K. and {Bedell}, Megan},
        title = "{Scalable Gaussian Processes for Integrated and Overlapping Measurements Via Augmented State Space Models}",
      journal = {arXiv e-prints},
     keywords = {Instrumentation and Methods for Astrophysics, Earth and Planetary Astrophysics, Solar and Stellar Astrophysics},
         year = 2026,
        month = jan,
          eid = {arXiv:2601.02527},
        pages = {arXiv:2601.02527},
          doi = {10.48550/arXiv.2601.02527},
archivePrefix = {arXiv},
       eprint = {2601.02527},
 primaryClass = {astro-ph.IM},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2026arXiv260102527R},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```

If in particular you are using `smolgp` to jointly model multiple datasets with exposure-informed GPs, please also cite [Luhn et al. 2026](https://ui.adsabs.harvard.edu/abs/2026arXiv260102462L/exportcitation):
```
@ARTICLE{2026arXiv260102462L,
       author = {{Luhn}, Jacob K. and {Rubenzahl}, Ryan A. and {Halverson}, Samuel and {Zhao}, Lily L.},
        title = "{Exposure-averaged Gaussian Processes for Combining Overlapping Datasets}",
      journal = {arXiv e-prints},
     keywords = {Instrumentation and Methods for Astrophysics, Earth and Planetary Astrophysics, Solar and Stellar Astrophysics},
         year = 2026,
        month = jan,
          eid = {arXiv:2601.02462},
        pages = {arXiv:2601.02462},
          doi = {10.48550/arXiv.2601.02462},
archivePrefix = {arXiv},
       eprint = {2601.02462},
 primaryClass = {astro-ph.IM},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2026arXiv260102462L},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```
